# MAVA Ontology

:::{note} The MAVA ontology has been generated from its source via
[pylode](https://github.com/RDFLib/pyLODE). You can open the ontology in full
page view <a href="mava-ontology.html" target="_blank">here</a>. :::

Or download the source files:

- [mava.ttl](https://github.com/sdsc-ordes/mava-exchange/blob/main/spec/mava.ttl) -
  Ontology in Turtle format
- [mava.shacl.ttl](https://github.com/sdsc-ordes/mava-exchange/blob/main/spec/mava.shacl.ttl) -
  SHACL validation shapes

<iframe src="mava-ontology.html" style="width: 100%; height: 80vh; border: none;"></iframe>
